# Contributing

1. fork and clone the project
2. install the dependencies above
3. run the tests with make:
    > make unit functional integration doctest
4. hack at will
5. commit, push etc
6. send a pull request

## keep in mind

![your lack of tests if disturbing the force](http://farm3.static.flickr.com/2248/2282734669_a7f431e660_o.jpg)

### that lettuce is a testing software, patches and pull requests must come with automated tests, and if suitable, with proper documentation.
